/************************************************************************
* COPYRIGHT:   Copyright    1999 PAXAR/Monarch Marking Systems
*
* FILE:        Super Demo
*
* SYSTEM:      Symbol Print API for Palm III.
* 
*
* DESCRIPTION: Provides a sample application for the Symbol Print API.*
*
* HISTORY:     09/21/99    Vern Litmer   Created
*              ...
*************************************************************************/

#include <Pilot.h>
#include <ptPrint.h>
#include "sDemo.h"
#include "about.h"
#include "info.h"
#include "sDemoRsc.h"

/***********************************************************************
 *
 *   Internal Constants
 *
 ***********************************************************************/
 
#define BuffSize				512

#define	sleep(x)				SysTaskDelay( (x) * sysTicksPerSecond )
#define FormGetValue(x)			CtlGetValue( GetObjectPtr ((x)) )
#define FormSetValue(x,y)		CtlSetValue( GetObjectPtr ((x)), (y) )

 
/***********************************************************************
 *
 *   Static Global variables
 *
 ***********************************************************************/
#pragma mark -- Global variables --

static	Boolean		gPrinterOpen	= false;
static	Word		gPrinterValue	= 9999;

static  PTTransport	gTransport		= PTUnknown;

static	ULong		gQueryBufLength = BuffSize;
static	char		gQueryBuf[ BuffSize ];
static	char		gQueryBufRes[ BuffSize ];


static	PTConnectSettings gSettings	= { 19200, 
									  	PTDefaultSerTimeout, 
									  	PTDefaultSerFlags,
									  	PTDefaultSerRecvBuf
									  };

static	CharPtr clearLine = "                                                          ";

CharPtr ptStatusSting[] = {

	"Successful and complete",
	"Operation failed",
	"Rom Incompatible",	
	"Bad Parameter",	
	"Transport not Available",
	"Line Error",
	"Transport not Opened",
	"Port already open",
	"No Memory",
	"Printer already connected",		
	"Printer not found",	
	"Time out occurred",	
	"Ir Status Pending",
	"No Peer Addr",
	"Bind failed",
	"No Ir Device Found",
	"Ir Discovery Failed",
	"Ir IrConnectReq Failed",
	"Ir ConnectIrLap Failed",
	"Ir Query Failed",
	"Error Reading Printcap info",
	"                                        "
};

#define PTClear	PTStatusPrintCapFailed + 1

typedef enum {
	cmdOpen = 0,
	cmdClose,
	cmdForm,
	cmdData1,
	cmdData2,
	cmdData3,
	cmdData4,
	cmdData5,
	cmdData6,	
	cmdQueryPrinter,
	cmdInitPrinter,
	cmdResetPrinter,
	cmdPrinterVersion,
	cmdHighLevelAPI
} cmdCommands;


typedef enum {
	queryBaudRate = 0,
	queryStopBit,
	queryParity,
	queryQuery,
	queryInit,
	queryReset
} queryPrintCap;


/***********************************************************************
 *
 *  Shared Global variables
 *
 ***********************************************************************/

Char 	gInfoLabel[134];
CharPtr gInfoLabelPtr = &gInfoLabel[0];

Char 	gInfo[1024];
CharPtr gInfoPtr = &gInfo[0];

/***********************************************************************
 *
 *   Internal Functions
 *
 ***********************************************************************/
#pragma mark -- Static Functions --

static DWord 	StarterPilotMain(Word cmd, Ptr cmdPBP, Word launchFlags);
static Boolean	AppHandleEvent( EventPtr eventP);
static void 	AppEventLoop(void);
static Err 		AppStart(void);
static void 	AppStop(void);

static PTStatus Connect();
static void		Disconnect();

static Boolean 	MainFormDoCommand(Word command);
static void 	MainFormInit( FormPtr frmP );
static void 	MainResetButtons (FormPtr frmP);
static Boolean 	MainFormHandleEvent(EventPtr eventP);

static void		PrinterClose();
static void 	PrinterInit();
static void 	PrinterOpen();
static void 	PrinterQuery();
static void 	PrinterReset();
static void		PrinterVersion();
static void		PrinterHighLevelAPI();

static void 	SendData( Word controlID );
// Various Receipts
static BytePtr 	BrownsHomeRepairData();
static BytePtr	FineIssuingData();
static BytePtr	RouteDeliveryData();
static BytePtr	ParkingPaymentData();
static BytePtr	HealthcareLabData();
static BytePtr	HomeBeautyData();

static BytePtr 	SetForm();

static void 	SetStatus( Int status );
static void		SetTrigerLabel(Word list, Word trigger, short index );

/***********************************************************************
 *
 * FUNCTION:    SetStatus
 *
 * DESCRIPTION: Prints a line
 *
 * PARAMETERS:  status - index to messages
 *
 * RETURNED: 
 *
 *
 ***********************************************************************/
 
static void SetStatus( Int status )
{
    WinDrawChars( &clearLine[0], StrLen( &clearLine[0] ), 40, 147 );
    WinDrawChars( ptStatusSting[status], StrLen(ptStatusSting[status]), 40, 147 );
}

/***********************************************************************
 *
 * FUNCTION:    MainFormDoCommand
 *
 * DESCRIPTION: This routine performs the menu command specified.
 *
 * PARAMETERS:  command  - menu item id
 *
 * RETURNED:    nothing
 *
 * REVISION HISTORY:
 *
 *
 ***********************************************************************/
 
static Boolean MainFormDoCommand(Word command)
{
	Boolean handled = false;

	switch (command)
	{
		case MainOptionsAboutMonarchSuperDemo:
		{
			MenuEraseStatus( 0 );
			FrmPopupForm( AboutForm );
			handled = true;
			break;
		}
		
		default:
		{
			break;
		}	
	}

	return handled;
}

/***********************************************************************
 *
 * FUNCTION:    SetSettings
 *
 * DESCRIPTION: Returns a PTConnectSettings.
 *
 * PARAMETERS:  
 *
 * RETURNED: Returns a PTConnectSettings.
 *
 *
 ***********************************************************************/

static PTConnectSettingsPtr SetSettings()
{
	gSettings.baudRate	= 19200;
	gSettings.recvBufSize = BuffSize;
	gSettings.timeOut	= PTDefaultSerTimeout;
	gSettings.flags		= serDefaultSettings | serSettingsFlagCTSAutoM;
	
	return &gSettings;
}	

/***********************************************************************
 *
 * FUNCTION:    SetForm
 *
 * DESCRIPTION: Sets the form information for a given printer.
 *
 * PARAMETERS:  
 *
 * RETURNED: BytePtr to the form.
 *
 *
 ***********************************************************************/
static BytePtr SetForm()
{
//---------------------------------------
// (18 hex) RE-INITIALIZES PALM PRINTER
//---------------------------------------
	return (BytePtr)"\x018";
					
}

/***********************************************************************
 *
 * FUNCTION:    BrownsHomeRepairData
 *
 * DESCRIPTION: Sets the data for a given printer.
 *
 * PARAMETERS:  
 *
 * RETURNED: BytePtr to the data.
 *
 *
 ***********************************************************************/
static BytePtr BrownsHomeRepairData()
{
	return (BytePtr)"\x01bP#\x01bk1\r\n" \
					"\x01bU1\r\n" \
	                "\x01C\r\n" \
	                "        BROWN'S\r\n" \
	                "     HOME REPAIRS\r\n\r\n" \
	                "\x01D\r\n" \
					"\x01bU0\r\n" \
	                "   DISHWASHER REPAIR\r\n\r\n\r\n" \
	                "    PARTS     10.50\n" \
	                "    LABOR     15.90\r\n\r\n\r\n" \
	                "    TOTAL    $26.40\r\n" \
					"\x01bk1\r\n\r\n" \
	                "\x01C\r\n" \
					"\x01bU1\r\n" \
	                "      SATISFACTION\n" \
	                "       GUARANTEED!\n" \
	                "\x00b";
}

/***********************************************************************
 *
 * FUNCTION:    FineIssuingData
 *
 * DESCRIPTION: Sets the data for a given printer.
 *
 * PARAMETERS:  
 *
 * RETURNED: BytePtr to the data.
 *
 *
 ***********************************************************************/
static BytePtr FineIssuingData()
{
	return (BytePtr)"\x01bP#\x01bk1\r\n" \
					"\x01C\r\n" \
					"         CAMPUS\r\n" \
					"        SECURITY\r\n" \
					"\x01bU1\r\n" \
	                "    ILLEGAL PARKING\r\n" \
	                "      ***TICKET***\r\n" \
					"\x01bU0\r\n" \
	                "    FINE:    $25.00\r\n" \
	                "\x01D\r\n\r\n\r\n\r\n" \
	                "    SEND PAYMENT TO:\r\n\r\n\r\n" \
	                "    CAMPUS SECURITY\r\n" \
	                "    1270 STATE ST\r\n" \
	                "    COLUMBUS, OHIO\r\n" \
	                "    ATTN: TRAFFIC\r\n\r\n" \
   	                "\x01bz1\x006\x032" \
   	                "A32675\n\x00b\n";
           
}

/***********************************************************************
 *
 * FUNCTION:    RouteDeliveryData
 *
 * DESCRIPTION: Sets the data for a given printer.
 *
 * PARAMETERS:  
 *
 * RETURNED: BytePtr to the data.
 *
 *
 ***********************************************************************/
static BytePtr RouteDeliveryData()
{
	return (BytePtr)"\x01bP#\x01bk1\r\n" \
					"\x01bU1\r\n" \
	                "\x01C\r\n" \
	                "      THE BREAD\r\n" \
	                "       COMPANY\r\n" \
					"\x01bU0\r\n" \
	                "     YOUR RECEIPT\r\n" \
	                "      THANK YOU\r\n\r\n" \
	                "\x01D\r\n" \
	                " 1 CASE LOAVES   19.80\n" \
	                "   7910520602\r\n\r\n" \
	                " 1 CASE BUNS     16.20\n" \
	                "   7848758588\r\n\r\n" \
	                " 1 CASE ROLLS    12.98\n" \
	                "   6589484738\r\n\r\n" \
	                " TAX              2.94\r\n" \
					"\x01bU1\n" \
	                "\x01C\n" \
	                " TOTAL          $51.92\n" \
					"\x01bU0\n" \
					"\x01D\n" \
					"\x00b\n";
}

/***********************************************************************
 *
 * FUNCTION:    ParkingPaymentData
 *
 * DESCRIPTION: Sets the data for a given printer.
 *
 * PARAMETERS:  
 *
 * RETURNED: BytePtr to the data.
 *
 *
 ***********************************************************************/
static BytePtr ParkingPaymentData()
{
	return (BytePtr)"\x01bP#\x01bk1\r\n" \
					"\x01bU1\r\n" \
	                "\x01C\r\n" \
	                "         SMITH\r\n" \
	                "       UNIVERSITY\r\n" \
	                "     FIGHTING LIONS\r\n" \
	                "\x01D\r\n" \
					"\x01bU0\r\n" \
	                "   10/22/00      LOT B\r\n\r\n\r\n\r\n" \
	                "   AMOUNT PAID  $10.50\r\n" \
	                "\x00b\n" \
	                "      OPEARATED BY\r\n" \
	                "     FIELDS PARKING\r\n" \
	                "        SERVICE\r\n" \
					"\x01bk1\r\n\r\n" \
	                "\x01C\r\n" \
					"\x01bU1\r\n" \
	                "   ****THANK YOU****\n" \
	                "\x01D\n" \
	                "\x01bU0\n\x00b\n";
}

/***********************************************************************
 *
 * FUNCTION:    HealthcareLabData
 *
 * DESCRIPTION: Sets the data for a given printer.
 *
 * PARAMETERS:  
 *
 * RETURNED: BytePtr to the data.
 *
 *
 ***********************************************************************/
static BytePtr HealthcareLabData()
{
	return (BytePtr)"\x01bP#\x01bk1\r\n" \
					"\x01bU1\r\n" \
	                "\x01C\r\n" \
	                "    HEALTHSOURCE OF\r\n" \
	                "      SPRINGFIELD\r\n" \
	                "\x01D\r\n" \
					"\x01bU0\r\n" \
	                "  TEST DATE:  3/31/00\r\n\r\n\r\n" \
	                "  TIME:  10:00 A.M.\r\n\r\n\r\n" \
	                "  HOSPITAL:  SYCAMORE\r\n\r\n\r\n" \
	                "      CHECK IN AT\r\n" \
	                "       OUTPATIENT\r\n" \
	                "      REGISTRATION\r\n" \
					"\x01bU1\r\n\r\n" \
					"         ******\n" \
	                "     DO NOT EAT OR\n" \
	                "      DRINK AFTER\n" \
	                "    MIDNIGHT BEFORE\n" \
	                "          TEST\n" \
					"         ******\n" \
	                "\x01bU0\n" \
   	                "\x01bz1\x006\x032" \
   	                "567500\n\x00b\n";

}

/***********************************************************************
 *
 * FUNCTION:    HomeBeautyData
 *
 * DESCRIPTION: Sets the data for a given printer.
 *
 * PARAMETERS:  
 *
 * RETURNED: BytePtr to the data.
 *
 *
 ***********************************************************************/
static BytePtr HomeBeautyData()
{
	return (BytePtr)"\x01bP#\x01bk1\r\n" \
					"\x01bU1\r\n" \
	                "\x01C\r\n" \
					" HOME BEAUTY SUPPLIES\n" \
	                "\x01D\r\n" \
					"   100 MyHome Road\n" \
					"  Anytown, US  54321\n" \
					" Phone: (123) 555-1234\r\n\r\n" \
					"     SALES RECEIPT\r\n\r\n" \
					"\x01bk2\r\n" \
					"Description      Qty.     Total\n" \
					"1. Lipstick       2       12.00\n" \
					"2. Polish         2       14.00\n" \
					"3. Fragrance      1        9.50\n" \
					"4. Lotion         1       10.50\n" \
					"                          -----\n" \
					"\x01bk1\r\n"
					"          Total    46.00\r\n\r\n" \
  	                " AMEX 37xyz55xx315001\n" \
  	                " Exp. Date 10/01\r\n\r\n\r\n" \
  	                "  \x01bz1\x006\x032" \
  	                "123456\n\x00b";

}
/***********************************************************************
 *
 * FUNCTION:    DoPrintCapQuery
 *
 * DESCRIPTION: Query the Printcap information
 *
 * PARAMETERS:  event - current event
 *
 * RETURNED: Displays the results in a popup form.
 *
 *
 ***********************************************************************/

static void DoPrintCapQuery(EventPtr event)
{
    PTStatus	status;
   
	if ( ! gPrinterOpen ) {
		FrmAlert( PrinterNotOpenAlert);
		return;
	}
	
	gQueryBufLength = BuffSize;	
	MemSet( &gQueryBuf[0], BuffSize, 0x0 );
	MemSet( &gQueryBufRes[0], gQueryBufLength, 0x0 );
	
	
	switch(event->data.popSelect.selection)
	{
		case queryBaudRate:
		{
			gQueryBuf[0] = 'b';
			gQueryBuf[1] = 'r';
			break; 
		}
		
		case queryStopBit:
		{
			gQueryBuf[0] = 's';
			gQueryBuf[1] = 'b';
			break; 
		}
		
		case queryParity:
		{
			gQueryBuf[0] = 'p';
			gQueryBuf[1] = 'r';
			break; 
		}
		
		case queryQuery:
		{
			gQueryBuf[0] = 'q';
			gQueryBuf[1] = 's';
			break; 
		}
		
		case queryInit:
		{
			gQueryBuf[0] = 'i';
			gQueryBuf[1] = 's';
			break; 
		}
		
		case queryReset:
		{
			gQueryBuf[0] = 'r';
			gQueryBuf[1] = 's';
			break; 
		}
		
	}
	
	SetStatus( PTClear );
	
	MemSet( gInfoPtr, 1024, 0x0 ); 
	MemSet( gInfoLabelPtr, 134, 0x0 ); 
	
	status = ptQueryPrintCap( (VoidPtr)&gQueryBuf[0], (VoidPtr)&gQueryBufRes[0], &gQueryBufLength );
	SetStatus( status );
	
	MemMove( gInfoLabelPtr, &gQueryBuf[0], StrLen( &gQueryBuf[0] ) + 1 );
	MemMove( gInfoPtr, &gQueryBufRes[0], gQueryBufLength );
	
	MemSet( gQueryBuf, BuffSize, 0x0 );
	MemSet( gQueryBufRes, BuffSize, 0x0 );			
		
	FrmPopupForm( InfoForm );	
	
}

/***********************************************************************
 *
 * FUNCTION:    SetTrigerLabel
 *
 * DESCRIPTION: Sets to label to the popup list to last command selected.
 *
 * PARAMETERS:  list - form list id
 *				trigger - object name of the list
 *				index - index of item in list 
 *
 * RETURNED: 
 *
 ***********************************************************************/
 
static void SetTrigerLabel(Word list, Word trigger, short index )
{

	ListPtr		pList;
	CharPtr		pLabel = NULL;
	
	pList = GetObjectPtr( list );
	pLabel = LstGetSelectionText(  pList, index );
	CtlSetLabel ( GetObjectPtr ( trigger ), pLabel );
	
}

/***********************************************************************
 *
 * FUNCTION:    PrinterClose
 *
 * DESCRIPTION: Execute the command ptClosePrinter API call.
 *
 * PARAMETERS:  EventPtr event
 *
 * RETURNED: 
 *
 ***********************************************************************/

static void PrinterClose( )
{

	PTStatus	status;
		
	SetStatus( PTClear );
					
	status = ptClosePrinter();
	SetStatus( status );
			
	gPrinterOpen = false;
}

/***********************************************************************
 *
 * FUNCTION:    PrinterInit
 *
 * DESCRIPTION: Execute the command PrinterInit API call.
 *
 * PARAMETERS:  none
 *
 * RETURNED:    none
 *
 ***********************************************************************/

static void PrinterInit()
{
	PTStatus	status;

	status = Connect();
	if ( PTStatusOK != status ) {
		return;
	}
	
	//----------------------
	// * Init the printer *
	//----------------------	
	SetStatus( PTClear );
	
	
	status = ptInitPrinter( NULL, 0 ); 
	SetStatus( PTClear );
							
	Disconnect();
	
}

/***********************************************************************
 *
 * FUNCTION:    PrinterOpen
 *
 * DESCRIPTION: Execute the command ptOpenPrinter API call.
 *
 * PARAMETERS:  
 *
 * RETURNED: 
 *
 ***********************************************************************/
static void PrinterOpen()
{
	PTConnectSettingsPtr pcSettings;
    PTStatus	status;

	SetStatus( PTClear );
	
	pcSettings = SetSettings();
	
	//status = ptOpenPrinter( "6015", gTransport, NULL );
	status = ptOpenPrinter( "6015", gTransport, pcSettings );

	if ( PTStatusOK != status ) {
		
		FrmAlert( OpenFailedAlert);
		
	}
	
	gPrinterOpen = true;
	
	SetStatus( status );

}


/***********************************************************************
 *
 * FUNCTION:    PrinterHighLevelAPI
 *
 * DESCRIPTION: Execute the command ptPrintApiVersion API call.
 *
 * PARAMETERS:  
 *
 * RETURNED: 
 *
 ***********************************************************************/
 
static void PrinterHighLevelAPI()
{
	PTStatus	status;
	
	UInt		i;
	ULong		length;
	
	char		pbuf[40];
	char		fontInfo[256];
	

	SetStatus( PTClear );
	
	status = ptStartPrintBuffer( 256 );
	if ( PTStatusOK != status ) {
		SetStatus( status );
		return;
	}

	for ( i = 1; i <= 4; i++ ) {
	
		StrPrintF( &pbuf[0], "%s : %i", "Loop index ", i );
		status = ptTextToBuffer( 30 + ( 5 * i ), i * 30, &pbuf[0] );
		if ( PTStatusOK != status && PTStatusPrintCapFailed != status) {
			ptResetPrintBuffer();
			SetStatus( status );
			return;
		}

		status = ptLineToBuffer( 30 + ( 5 * i  ), 
						20 + ( i * 30 ), 
						i * 120, 
						20 + ( i * 30 ), 
						i );
		if ( PTStatusOK != status && PTStatusPrintCapFailed != status) {
			ptResetPrintBuffer();
			SetStatus( status );
			return;
		}
	}

	status = ptTextToBuffer( 30, 240, "Next to last." );
	if ( PTStatusOK != status && PTStatusPrintCapFailed != status) {
			ptResetPrintBuffer();
			SetStatus( status );
			return;
	}

	
	status = ptRectToBuffer( 20, 215, 200, 280, 4 );
	if ( PTStatusOK != status && PTStatusPrintCapFailed != status) {
			ptResetPrintBuffer();
			SetStatus( status );
			return;
	}

	
	length = 256;
	status = ptQueryPrintCap( "f1", &fontInfo[0], &length );
	if ( PTStatusOK == status ) {
		
		ptSetFont( &fontInfo[0] );
	}
	
	status = ptTextToBuffer( 30, 300, "The last line." );
	if ( PTStatusOK != status && PTStatusPrintCapFailed != status) {
			ptResetPrintBuffer();
			SetStatus( status );
			return;
	}

	
	status = ptLineToBuffer( 30, 340, 500, 340, 11 );
	if ( PTStatusOK != status && PTStatusPrintCapFailed != status) {
			ptResetPrintBuffer();
			SetStatus( status );
			return;
	}
		
	status = ptPrintPrintBuffer( NULL );
	if ( PTStatusOK != status ) {
			ptResetPrintBuffer();
	}
	SetStatus( status );

}

/***********************************************************************
 *
 * FUNCTION:    SendData
 *
 * DESCRIPTION: Write data (data or form) to the printer.
 *
 * PARAMETERS:  controlID - list item value
 *
 * RETURNED: 
 *
 ***********************************************************************/
 
static void SendData( Word controlID )
{
    BytePtr				 pData;
    PTStatus			 status;
    
	//------------------
	// * Set the data *
	//------------------
	switch ( controlID )
	{
		case cmdForm:
		{
			pData = SetForm();
			break;
		}
		
		case cmdData1:
		{
			pData = BrownsHomeRepairData();
			break;
		}

		case cmdData2:
		{
			pData = FineIssuingData();
			break;
		}
		
		case cmdData3:
		{
			pData = RouteDeliveryData();
			break;
		}

		case cmdData4:
		{
			pData = ParkingPaymentData();
			break;
		}

		case cmdData5:
		{
			pData = HealthcareLabData();
			break;
		}

		case cmdData6:
		{
			pData = HomeBeautyData();
			break;
		}

		default:
		{
			pData = (BytePtr)"debug string                           ";
			break;
		}
	}

    if (!pData)
    {
	    return;
    }
       	
	status = Connect();
	if ( PTStatusOK != status ) {
		return;
	}
	
	//-----------------------------------
	// * Write the form to the printer *
	//-----------------------------------	
	SetStatus( PTClear );
	
	status = ptWritePrinter( pData, StrLen( (CharPtr)pData ) );		
	SetStatus( status );

	Disconnect();
}
	
/***********************************************************************
 *
 * FUNCTION:    Disconnect
 *
 * DESCRIPTION: Execute the command ptDisconnectPrinter() API call.
 *
 * PARAMETERS: 
 *
 * RETURNED: 
 *
 ***********************************************************************/
 	
static void Disconnect()
{	
	SetStatus(  PTClear );
	SetStatus( ptDisconnectPrinter() );					
}

/***********************************************************************
 *
 * FUNCTION:    Connect
 *
 * DESCRIPTION: Execute the command ptConnectPrinter() API call.
 *
 * PARAMETERS:  
 *
 * RETURNED: 	PTStatus result code
 *
 ***********************************************************************/
 			
static PTStatus Connect()
{

	PTStatus status;

	SetStatus( PTStatusOK );
	
	//--------------
	// * Connect *
	//--------------
	SetStatus( PTClear );
				
	status = ptConnectPrinter( NULL );
	SetStatus( status );
	
	return status;
		
}

/***********************************************************************
 *
 * FUNCTION:    MainFormInit
 *
 * DESCRIPTION: This routine initializes the MainForm form.
 *
 * PARAMETERS:  frm - pointer to the MainForm form.
 *
 * RETURNED:    nothing
 *
 * REVISION HISTORY:
 *
 *
 ***********************************************************************/
static void MainFormInit(FormPtr frmP)
{
	gTransport = PTSerial;
}

/***********************************************************************
 *
 * FUNCTION:    MainResetButtons 
 *
 * DESCRIPTION: Reset the Radio Buttons, Highlights the 1 RADIO BUTTON
 * 
 * PARAMETERS:  
 *
 * RETURNED:
 *
 ***********************************************************************/
void MainResetButtons (FormPtr frmP)
{
   Word wIDPPOne = FrmGetObjectIndex (frmP, Main1PushButton );
   ControlPtr pCtlPPOne = (ControlPtr) FrmGetObjectPtr (frmP, wIDPPOne);

   Word wIDPPTwo = FrmGetObjectIndex (frmP, Main2PushButton );
   ControlPtr pCtlPPTwo = (ControlPtr) FrmGetObjectPtr (frmP, wIDPPTwo);

   Word wIDPPThree = FrmGetObjectIndex (frmP, Main3PushButton );
   ControlPtr pCtlPPThree = (ControlPtr) FrmGetObjectPtr (frmP, wIDPPThree);

   Word wIDPPFour = FrmGetObjectIndex (frmP, Main4PushButton );
   ControlPtr pCtlPPFour = (ControlPtr) FrmGetObjectPtr (frmP, wIDPPFour);

   Word wIDPPFive = FrmGetObjectIndex (frmP, Main5PushButton );
   ControlPtr pCtlPPFive = (ControlPtr) FrmGetObjectPtr (frmP, wIDPPFive);
   
   Word wIDPPSix = FrmGetObjectIndex (frmP, Main6PushButton );
   ControlPtr pCtlPPSix = (ControlPtr) FrmGetObjectPtr (frmP, wIDPPSix);


	//-----------------------------------------------------------------
	// Initialize the Radio Buttons to 1 (Default)
	// Note that because this is grouped, user taps will automatically 
	// turn off the untapped selections, but programmatically we have to
	// do it ourselves.
	//------------------------------------------------------------------
   
   CtlSetValue ( pCtlPPOne, 1 );
   CtlSetValue ( pCtlPPTwo, 0 );
   CtlSetValue ( pCtlPPThree, 0 );
   CtlSetValue ( pCtlPPFour, 0 );
   CtlSetValue ( pCtlPPFive, 0 );
   CtlSetValue ( pCtlPPSix, 0 );

}

/***********************************************************************
 *
 * FUNCTION:    MainFormHandleEvent
 *
 * DESCRIPTION: This routine is the event handler for the 
 *              "MainForm" of this application.
 *
 * PARAMETERS:  eventP  - a pointer to an EventType structure
 *
 * RETURNED:    true if the event has handle and should not be passed
 *              to a higher level handler.
 *
 * REVISION HISTORY:
 *
 *
 ***********************************************************************/

static Boolean MainFormHandleEvent(EventPtr eventP)
{
    Boolean		handled = false;
	Word		controlID;
    FormPtr		frmP;
   	
	switch (eventP->eType) 
	{
		case frmOpenEvent:
		{
			frmP = FrmGetActiveForm();
			
			MainFormInit( frmP );
			MainResetButtons ( frmP );
			FrmDrawForm ( frmP );
			
			SetStatus( PTStatusOK );
					
			handled = true;
			break;
		}
		
		case popSelectEvent:
		{
			break;
		}
		
		case menuEvent:
		{
			return MainFormDoCommand(eventP->data.menu.itemID);
			handled = true;
			break;
		}

		case ctlSelectEvent:
		{
			switch( eventP->data.ctlSelect.controlID )
			{
				case MainPrintSampleButton:
				{
					FormPtr frmP = FrmGetActiveForm();

					Word wIDPPOne = FrmGetObjectIndex (frmP, Main1PushButton );
					ControlPtr pCtlPPOne = (ControlPtr) FrmGetObjectPtr (frmP, wIDPPOne);

					Word wIDPPTwo = FrmGetObjectIndex (frmP, Main2PushButton );
					ControlPtr pCtlPPTwo = (ControlPtr) FrmGetObjectPtr (frmP, wIDPPTwo);

					Word wIDPPThree = FrmGetObjectIndex (frmP, Main3PushButton );
					ControlPtr pCtlPPThree = (ControlPtr) FrmGetObjectPtr (frmP, wIDPPThree);

					Word wIDPPFour = FrmGetObjectIndex (frmP, Main4PushButton );
					ControlPtr pCtlPPFour = (ControlPtr) FrmGetObjectPtr (frmP, wIDPPFour);
	
					Word wIDPPFive = FrmGetObjectIndex (frmP, Main5PushButton );
					ControlPtr pCtlPPFive = (ControlPtr) FrmGetObjectPtr (frmP, wIDPPFive);
					
				   	Word wIDPPSix = FrmGetObjectIndex (frmP, Main6PushButton );
   					ControlPtr pCtlPPSix = (ControlPtr) FrmGetObjectPtr (frmP, wIDPPSix);
				
					if ( CtlGetValue ( pCtlPPOne) )
					{
						if ( gPrinterOpen )
						{
							controlID = gPrinterValue;
						}
						PrinterOpen( );					
						SendData( cmdForm );
						SendData( cmdData1 );
						PrinterClose( );
					}

					else if ( CtlGetValue ( pCtlPPTwo) )
					{
						if ( gPrinterOpen )
						{
							controlID = gPrinterValue;
						}
						PrinterOpen( );					
						SendData( cmdForm );
						SendData( cmdData2 );
						PrinterClose( );
					}

					else if ( CtlGetValue ( pCtlPPThree) )
					{
						if ( gPrinterOpen )
						{
							controlID = gPrinterValue;
						}
						PrinterOpen( );					
						SendData( cmdForm );
						SendData( cmdData3 );
						PrinterClose( );
					}

					else if ( CtlGetValue ( pCtlPPFour) )
					{
						if ( gPrinterOpen )
						{
							controlID = gPrinterValue;
						}
						PrinterOpen( );					
						SendData( cmdForm );
						SendData( cmdData4 );
						PrinterClose( );
					}

					else if( CtlGetValue ( pCtlPPFive) )
					{
						if ( gPrinterOpen )
						{
							controlID = gPrinterValue;
						}
					
						PrinterOpen( );					
						SendData( cmdForm );
						SendData( cmdData5 );
						PrinterClose( );
					}
					
					else if( CtlGetValue ( pCtlPPSix) )
					{
						if ( gPrinterOpen )
						{
							controlID = gPrinterValue;
						}
					
						PrinterOpen( );					
						SendData( cmdForm );
						SendData( cmdData6 );
						PrinterClose( );
					}
					
					handled = true;
					break;
				}
	
				break;
			} // Case MainPrintButton
		
    		default:
    		{
    			break;
    		}
		
   		} // End Switch 
    
    }     	
	
	return handled;
}


/***********************************************************************
 *
 * FUNCTION:    AppHandleEvent
 *
 * DESCRIPTION: This routine loads form resources and set the event
 *              handler for the form loaded.
 *
 * PARAMETERS:  event  - a pointer to an EventType structure
 *
 * RETURNED:    true if the event has handle and should not be passed
 *              to a higher level handler.
 *
 * REVISION HISTORY:
 *
 *
 ***********************************************************************/
 
static Boolean AppHandleEvent( EventPtr eventP)
{
	Word formId;
	FormPtr frmP;

	if (eventP->eType == frmLoadEvent) {
	
		//-----------------------------
		// * Load the form resource. *
		//-----------------------------
		formId = eventP->data.frmLoad.formID;
		frmP = FrmInitForm(formId);
		FrmSetActiveForm(frmP);

		//--------------------------------------------------------------------
		// * Set the event handler for the form.  The handler of the currently
		// * active form is called by FrmHandleEvent each time is receives an
		// * event.
		//-------------------------------------------------------------------- 
		switch (formId)
		{
			case MainForm:
			{
				FrmSetEventHandler(frmP, MainFormHandleEvent);
				break;
			}
				
			case AboutForm:
			{
				FrmSetEventHandler( frmP, AboutHandleEvent );
				break;
			}
			
			case InfoForm:
			{
				FrmSetEventHandler( frmP, InfoHandleEvent );
				break;
			}
			
			default:
			{
				break;

			}

			return true;
		}
	}
	
	return false;
}


/***********************************************************************
 *
 * FUNCTION:    AppEventLoop
 *
 * DESCRIPTION: This routine is the event loop for the application.  
 *
 * PARAMETERS:  nothing
 *
 * RETURNED:    nothing
 *
 * REVISION HISTORY:
 *
 *
 ***********************************************************************/
 
static void AppEventLoop(void)
{
	Word error;
	EventType event;


	do {
		EvtGetEvent(&event, evtWaitForever);
		
		
		if (! SysHandleEvent(&event))
			if (! MenuHandleEvent(0, &event, &error))
				if (! AppHandleEvent(&event))
					FrmDispatchEvent(&event);

	} while (event.eType != appStopEvent);
}


/***********************************************************************
 *
 * FUNCTION:     AppStart
 *
 * DESCRIPTION:  Get the current application's preferences.
 *
 * PARAMETERS:   nothing
 *
 * RETURNED:     Err value 0 if nothing went wrong
 *
 * REVISION HISTORY:
 *
 *
 ***********************************************************************/
 
static Err AppStart(void)
{	
   return 0;
}


/***********************************************************************
 *
 * FUNCTION:    AppStop
 *
 * DESCRIPTION: Save the current state of the application.
 *
 * PARAMETERS:  nothing
 *
 * RETURNED:    nothing
 *
 * REVISION HISTORY:
 *
 *
 ***********************************************************************/
 
static void AppStop(void)
{
  	ptClosePrinter();
}


/***********************************************************************
 *
 * FUNCTION:    StarterPilotMain
 *
 * DESCRIPTION: This is the main entry point for the application.
 * PARAMETERS:  cmd - word value specifying the launch code. 
 *              cmdPB - pointer to a structure that is associated with the launch code. 
 *              launchFlags -  word value providing extra information about the launch.
 *
 * RETURNED:    Result of launch
 *
 * REVISION HISTORY:
 *
 *
 ***********************************************************************/
 
static DWord StarterPilotMain(Word cmd, Ptr cmdPBP, Word launchFlags)
{
	Err error;

	switch (cmd)
		{
		case sysAppLaunchCmdNormalLaunch:
			error = AppStart();
			if (error) 
				return error;
				
			FrmGotoForm(MainForm);
			AppEventLoop();
			AppStop();
			break;

		default:
			break;

		}
	
	return 0;
}

/***********************************************************************
 *
 * FUNCTION:    GetObjectPtr
 *
 * DESCRIPTION: Returns a pointer to an object in the current form.
 *
 * PARAMETERS:  objectID 
 *
 * RETURNED:    VoidPtr
 *
 * REVISION HISTORY:
 *
 ***********************************************************************/
 
VoidPtr GetObjectPtr(Word objectID)
{
	FormPtr frmP;

	frmP = FrmGetActiveForm();
	return ( FrmGetObjectPtr( frmP, FrmGetObjectIndex(frmP, objectID) ) );
}

/***********************************************************************
 *
 * FUNCTION:    PilotMain
 *
 * DESCRIPTION: This is the main entry point for the application.
 *
 * PARAMETERS:  cmd - word value specifying the launch code. 
 *              cmdPB - pointer to a structure that is associated with the launch code. 
 *              launchFlags -  word value providing extra information about the launch.
 * RETURNED:    Result of launch
 *
 * REVISION HISTORY:
 *
 *
 ***********************************************************************/
DWord PilotMain( Word cmd, Ptr cmdPBP, Word launchFlags)
{
    return StarterPilotMain(cmd, cmdPBP, launchFlags);
}

